==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebExporterEventEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebExporterEventDetailDescriptionMetadata } from "./WebExporterEventDetailDescriptionMetadata";
import { WebExporterEventEventArgsDescription } from "./WebExporterEventEventArgsDescription";
/**
 * @hidden
 */
var WebExporterEventEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebExporterEventEventArgsDescriptionMetadata, _super);
    function WebExporterEventEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebExporterEventEventArgsDescriptionMetadata.b = function (a) {
        if (WebExporterEventEventArgsDescriptionMetadata.a == null) {
            WebExporterEventEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebExporterEventEventArgsDescriptionMetadata.c(WebExporterEventEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebExporterEventEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebExporterEventEventArgsDescriptionMetadata.a);
        WebExporterEventDetailDescriptionMetadata.d(a);
    };
    WebExporterEventEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ExporterEventEventArgs");
        a.item("Detail", "ExportedType:WebExporterEventDetail");
    };
    WebExporterEventEventArgsDescriptionMetadata.d = function (a) {
        WebExporterEventEventArgsDescriptionMetadata.b(a);
        a.aa("WebExporterEventEventArgs", function () { return new WebExporterEventEventArgsDescription(); });
        a.z("WebExporterEventEventArgs", WebExporterEventEventArgsDescriptionMetadata.a);
    };
    WebExporterEventEventArgsDescriptionMetadata.$t = markType(WebExporterEventEventArgsDescriptionMetadata, 'WebExporterEventEventArgsDescriptionMetadata');
    WebExporterEventEventArgsDescriptionMetadata.a = null;
    return WebExporterEventEventArgsDescriptionMetadata;
}(Base));
export { WebExporterEventEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebExporterEventEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebExporterEventDetailDescriptionMetadata } from "./WebExporterEventDetailDescriptionMetadata";
import { WebExporterEventEventArgsDescription } from "./WebExporterEventEventArgsDescription";
/**
 * @hidden
 */
var WebExporterEventEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebExporterEventEventArgsDescriptionMetadata, _super);
    function WebExporterEventEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebExporterEventEventArgsDescriptionMetadata.b = function (a) {
        if (WebExporterEventEventArgsDescriptionMetadata.a == null) {
            WebExporterEventEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebExporterEventEventArgsDescriptionMetadata.c(WebExporterEventEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebExporterEventEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebExporterEventEventArgsDescriptionMetadata.a);
        WebExporterEventDetailDescriptionMetadata.d(a);
    };
    WebExporterEventEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ExporterEventEventArgs");
        a.item("Detail", "ExportedType:WebExporterEventDetail");
    };
    WebExporterEventEventArgsDescriptionMetadata.d = function (a) {
        WebExporterEventEventArgsDescriptionMetadata.b(a);
        a.ac("WebExporterEventEventArgs", function () { return new WebExporterEventEventArgsDescription(); });
        a.ab("WebExporterEventEventArgs", WebExporterEventEventArgsDescriptionMetadata.a);
    };
    WebExporterEventEventArgsDescriptionMetadata.$t = markType(WebExporterEventEventArgsDescriptionMetadata, 'WebExporterEventEventArgsDescriptionMetadata');
    WebExporterEventEventArgsDescriptionMetadata.a = null;
    return WebExporterEventEventArgsDescriptionMetadata;
}(Base));
export { WebExporterEventEventArgsDescriptionMetadata };
